USE [census]
GO

CREATE SPATIAL INDEX [idx_geog_auto_zipcodes] ON [dbo].[zipcodes] 
(
	[shapegeog]
)USING  GEOGRAPHY_AUTO_GRID 
WITH (
CELLS_PER_OBJECT = 16, PAD_INDEX  = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

CREATE SPATIAL INDEX [idx_geog_auto_zipcodes2] ON [dbo].[zipcodes] 
(
	[shapegeog]
)USING  GEOGRAPHY_AUTO_GRID 
WITH (
CELLS_PER_OBJECT = 16, DATA_COMPRESSION = PAGE, PAD_INDEX  = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO


declare @geog geography
select @geog = shapegeog from congress where id = 116

DECLARE @x xml;
EXEC sp_help_spatial_geography_index_xml 'dbo.zipcodes', 'idx_geog_zipcodes', 1, @geog, @x output;
SELECT @x

declare @geog geography
select @geog = shapegeog from congress where id = 116

DECLARE @x xml;
EXEC sp_help_spatial_geography_index_xml 'dbo.zipcodes', 'idx_geog_auto_zipcodes', 1, @geog, @x output;
SELECT @x

-- uses idx_zipcodes_low without hint, 1 second
select * from zipcodes z 
join Congress c
on z.shapegeog.STIntersects(c.shapegeog)=1
where c.id = 116

-- hints idx_geog_zipcodes, 1 second
select * from zipcodes z with (index=idx_geog_zipcodes)
join Congress c
on z.shapegeog.STIntersects(c.shapegeog)=1
where c.id = 116

-- hints idx_geog_auto_zipcodes, 1 second
select * from zipcodes z with (index=idx_geog_auto_zipcodes)
join Congress c
on z.shapegeog.STIntersects(c.shapegeog)=1
where c.id = 116

-- 17 sec, uses idx_geog_zipcodes
select * from zipcodes z 
join Congress c
on z.shapegeog.STIntersects(c.shapegeog)=1
where c.id > 630

-- 24 sec with auto_index
select * from zipcodes z with (index=idx_geog_auto_zipcodes)
join Congress c
on z.shapegeog.STIntersects(c.shapegeog)=1
where c.id > 630

-- 26 sec with low index
select * from zipcodes z with (index=idx_geog_zipcodes_low)
join Congress c
on z.shapegeog.STIntersects(c.shapegeog)=1
where c.id > 630


CREATE SPATIAL INDEX [idx_geom_auto_zipcodes] ON [dbo].[zipcodes] 
(
	[shape]
)USING  GEOMETRY_AUTO_GRID 
WITH (
BOUNDING_BOX =(17, -180, 72, -60),  
CELLS_PER_OBJECT = 16, PAD_INDEX  = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

declare @geom geometry
select @geom = shape from congress where id = 116

DECLARE @x xml;
EXEC sp_help_spatial_geometry_index_xml 'dbo.zipcodes', 'idx_geom_auto_zipcodes', 1, @geom, @x output;
SELECT @x

declare @geom geometry
select @geom = shape from congress where id = 116

DECLARE @x xml;
EXEC sp_help_spatial_geometry_index_xml 'dbo.zipcodes', 'idx_geom_zipcodes', 1, @geom, @x output;
SELECT @x

-- chooses idx_geom_zipcodes, 11 seconds
select * from zipcodes z 
join Congress c
on z.shape.STIntersects(c.shape)=1
where c.id > 630

-- chooses idx_geom_zipcodes, 10 seconds
select * from zipcodes z with (index=idx_geom_auto_zipcodes)
join Congress c
on z.shape.STIntersects(c.shape)=1
where c.id > 630

-- 14 seconds, chooses auto index 
select * from zipcodes z 
join AdventureWorks2008R2.Person.Address a
on z.shapegeog.STIntersects(a.SpatialLocation)=1
where AddressID < 1000

-- 21 seconds, hhhh index
select * from zipcodes z with (index=idx_geog_zipcodes)
join AdventureWorks2008R2.Person.Address a
on z.shapegeog.STIntersects(a.SpatialLocation)=1
where AddressID < 1000

-- 54 seconds, LLLL index
select * from zipcodes z with (index=idx_geog_zipcodes_low)
join AdventureWorks2008R2.Person.Address a
on z.shapegeog.STIntersects(a.SpatialLocation)=1
where AddressID < 1000

declare @geog geography
select @geog = SpatialLocation from AdventureWorks2008R2.Person.Address where AddressID = 1
DECLARE @x xml;
EXEC sp_help_spatial_geography_index_xml 'dbo.zipcodes', 'idx_geog_zipcodes', 1, @geog, @x output;
SELECT @x

declare @geog geography
select @geog = SpatialLocation from AdventureWorks2008R2.Person.Address where AddressID = 1
DECLARE @x xml;
EXEC sp_help_spatial_geography_index_xml 'dbo.zipcodes', 'idx_geog_auto_zipcodes', 1, @geog, @x output;
SELECT @x