drop table t1
go

create table t1(
 id int identity primary key,
 geom1 geometry,
 -- columns based on one spatial object
 geomx as geom1.STPointN(2).STX persisted,
 geomy as geom1.STPointN(2).STY persisted,
 geoma as geom1.STArea() persisted,
 geoml as geom1.STLength() persisted,
 geom2 geometry,
 -- columns based on spatial construction
 ugeomx as geom1.STUnion(geom2).STPointN(2).STX persisted,
 ugeomy as geom1.STUnion(geom2).STPointN(2).STY persisted,
 ugeoma as geom1.STUnion(geom2).STArea() persisted,
 ugeoml as geom1.STUnion(geom2).STLength() persisted,
 -- columns based on two-column operation
 uinter as geom1.STIntersection(geom2).STIntersects(geom1) persisted
)
go

-- original example
declare @g1 geometry = 'POLYGON((0 0,82.339026 0, 82.339026 29.661245, 0 29.661245, 0 0))'
declare @g2 geometry = 'POINT(0 0)'
insert t1 (geom1, geom2) values(@g1, @g2)

-- Alestair's example
DECLARE @line1 geometry = 'LINESTRING(0 11, 430 310)';
DECLARE @line2 geometry = 'LINESTRING(0 500, 650 0)';
insert t1 (geom1, geom2) values(@line1, @line2)

select * from t1

select geomx, geomy, geoma, geoml, ugeomx, ugeomy, ugeoma, ugeoml, uinter
from t1

/* Denali
geomx	    geomy	geoma				geoml				ugeomx				ugeomy				ugeoma				ugeoml					uinter
82.339026	0		2442.27802324737	224.000542			82.339026			0					2442.27802324737	224.000542				1
430			310		0					523.737529684479	333.884206669111	243.165994869916	0					1343.79850302731		1

SQL Server 2008 R2

geomx		geomy	geoma				geoml				ugeomx				ugeomy				ugeoma				ugeoml					uinter
82.339026	0		2442.27799757342	224.000542			82.3390254974365	0					2442.27799757342	224.000540733337		1
430			310		0					523.737529684479	333.88420666911		243.165994869916	0					1343.79850302731		0

*/